@@ -5,6 +5,7 @@ import mimetypes
 import asyncio
 from tornado.ioloop import IOLoop
 import time
+import cortx_constants
 
 from tornado.web import HTTPError as HTTPServerError
 import base64
@@ -26,6 +27,7 @@ import nbformat
 import json
 
 Config = namedtuple('Config', [
+    
  'prefix', 'region', 'bucket_name', 'host_name', 'cortx_authenticator',
     'multipart_uploads', 'endpoint_url'
 ])
@@ -97,12 +99,7 @@ class CortxJupyter(ContentsManager):
     def _default_authentication(self):
         return self.authentication_class(parent=self)
 
-    # Do not use a checkpoints class: the rest of the system
-    # only expects a ContentsManager
     checkpoints_class = None
-
-    # Some of the write functions contain multiple S3 call
-    # We do what we can to prevent bad things from happening
     write_lock = Instance(Lock)
 
     @default('write_lock')
@@ -203,19 +200,16 @@ class CortxJupyter(ContentsManager):
         )
 
 
-def _key(context, path):
-    return context.prefix + path.lstrip('/')
+def _key(config, path):
+    return config.prefix + path.lstrip('/')
 
-def _path(context, key):
-    return '/' + key[len(context.prefix):]
+def _path(config, key):
+    return '/' + key[len(config.prefix):]
 
 
 def _final_path_component(key_or_path):
     return key_or_path.split('/')[-1]
 
-
-# The sort keys keep the UI as reasonable as possible with long running
-# actions acting on multiple objects, including if things fail in the middle
 def _copy_sort_key(key):
     return (key.count('/'), 0 if key.endswith(cortx_constants['FOLDER_SEPERATOR']) else 1)
 
@@ -223,19 +217,16 @@ def _copy_sort_key(key):
 def _delete_sort_key(key):
     return tuple(-1 * key_i for key_i in _copy_sort_key(key))
 
-
-# We don't save type/format to S3, so we do some educated guesswork
-# as to the types/formats of returned values.
 @gen.coroutine
-def _type_from_path(context, path):
+def _type_from_path(config, path):
     type = \
         'notebook' if path.endswith(cortx_constants["NB_TYPE"]) else \
-        'directory' if _is_root(path) or (yield _dir_exists(context, path)) else \
+        'directory' if _is_root(path) or (yield _dir_exists(config, path)) else \
         'file'
     return type
 
 
-def _format_from_type_and_path(context, type, path):
+def _format_from_type_and_path(config, type, path):
     type = \
         'json' if type == 'notebook' else \
         'json' if type == 'directory' else \
@@ -252,8 +243,8 @@ def _type_from_path_not_directory(path):
 
 
 @gen.coroutine
-def _dir_exists(context, path):
-    return True if _is_root(path) else (yield _file_exists(context, path + cortx_constants["FOLDER_SEPERATOR"]))
+def _dir_exists(config, path):
+    return True if _is_root(path) else (yield _file_exists(config, path + cortx_constants["FOLDER_SEPERATOR"]))
 
 
 def _is_root(path):
@@ -263,13 +254,13 @@ def _is_root(path):
 
 
 @gen.coroutine
-def _file_exists(context, path):
+def _file_exists(config, path):
 
     @gen.coroutine
     def key_exists():
-        key = _key(context, path)
+        key = _key(config, path)
         try:
-            response = yield _head_object(context, context.bucket_name, key)
+            response = yield _head_object(config, config.bucket_name, key)
             
         except HTTPClientError as exception:
             if exception.response.code != 404:
@@ -282,38 +273,38 @@ def _file_exists(context, path):
 
 
 @gen.coroutine
-def _exists(context, path):
-    return (yield _file_exists(context, path)) or (yield _dir_exists(context, path))
+def _exists(config, path):
+    return (yield _file_exists(config, path)) or (yield _dir_exists(config, path))
 
 
 @gen.coroutine
-def _get(context, path, content, type, format):
-    type_to_get = type if type is not None else (yield _type_from_path(context, path))
-    format_to_get = format if format is not None else _format_from_type_and_path(context, type_to_get, path)
-    return (yield GETTERS[(type_to_get, format_to_get)](context, path, content))
+def _get(config, path, content, type, format):
+    type_to_get = type if type is not None else (yield _type_from_path(config, path))
+    format_to_get = format if format is not None else _format_from_type_and_path(config, type_to_get, path)
+    return (yield GETTERS[(type_to_get, format_to_get)](config, path, content))
 
 
 @gen.coroutine
-def _get_notebook(context, path, content):
-    notebook_dict = yield _get_any(context, path, content, 'notebook', None, 'json', lambda file_bytes: json.loads(file_bytes.decode('utf-8')))
+def _get_notebook(config, path, content):
+    notebook_dict = yield _get_any(config, path, content, 'notebook', None, 'json', lambda file_bytes: json.loads(file_bytes.decode('utf-8')))
     return nbformat.from_dict(notebook_dict)
 
 
 @gen.coroutine
-def _get_file_base64(context, path, content):
-    return (yield _get_any(context, path, content, 'file', 'application/octet-stream', 'base64', lambda file_bytes: base64.b64encode(file_bytes).decode('utf-8')))
+def _get_file_base64(config, path, content):
+    return (yield _get_any(config, path, content, 'file', 'application/octet-stream', 'base64', lambda file_bytes: base64.b64encode(file_bytes).decode('utf-8')))
 
 
 @gen.coroutine
-def _get_file_text(context, path, content):
-    return (yield _get_any(context, path, content, 'file', 'text/plain', 'text', lambda file_bytes: file_bytes.decode('utf-8')))
+def _get_file_text(config, path, content):
+    return (yield _get_any(config, path, content, 'file', 'text/plain', 'text', lambda file_bytes: file_bytes.decode('utf-8')))
 
 
 @gen.coroutine
-def _get_any(context, path, content, type, mimetype, format, decode):
+def _get_any(config, path, content, type, mimetype, format, decode):
     method = 'GET' if content else 'HEAD'
-    key = _key(context, path)
-    response = yield _get_object(context, context.bucket_name, key)
+    key = _key(config, path)
+    response = yield _get_object(config, config.bucket_name, key)
     file_bytes = response['Body'].read()
     last_modified_str = response['LastModified']
     if not isinstance(last_modified_str, str):
@@ -336,11 +327,11 @@ def _get_any(context, path, content, type, mimetype, format, decode):
 
 
 @gen.coroutine
-def _get_directory(context, path, content):
-    key = _key(context, path)
+def _get_directory(config, path, content):
+    key = _key(config, path)
     key_prefix = key if (key == '' or key[-1] == '/') else (key + '/')
     keys, directories = \
-        (yield _list_immediate_child_keys_and_directories(context, key_prefix)) if content else \
+        (yield _list_immediate_child_keys_and_directories(config, key_prefix)) if content else \
         ([], [])
 
     all_keys = {key for (key, _) in keys}
@@ -358,7 +349,7 @@ def _get_directory(context, path, content):
             {
                 'type': 'directory',
                 'name': _final_path_component(directory),
-                'path': _path(context, directory),
+                'path': _path(config, directory),
             }
             for directory in directories
             if directory not in all_keys
@@ -366,7 +357,7 @@ def _get_directory(context, path, content):
             {
                 'type': _type_from_path_not_directory(key),
                 'name': _final_path_component(key),
-                'path': _path(context, key),
+                'path': _path(config, key),
                 'last_modified': last_modified,
             }
             for (key, last_modified) in keys
@@ -376,12 +367,12 @@ def _get_directory(context, path, content):
 
 
 @gen.coroutine
-def _save(context, model, path):
-    type_to_save = model['type'] if 'type' in model else (yield _type_from_path(context, path))
+def _save(config, model, path):
+    type_to_save = model['type'] if 'type' in model else (yield _type_from_path(config, path))
     format_to_save = model['format'] if 'format' in model else _format_from_type_and_path(
-        context, type_to_save, path)
+        config, type_to_save, path)
     return (yield SAVERS[(type_to_save, format_to_save)](
-        context,
+        config,
         model['chunk'] if 'chunk' in model else None,
         model['content'] if 'content' in model else None,
         path,
@@ -389,56 +380,56 @@ def _save(context, model, path):
 
 
 @gen.coroutine
-def _save_notebook(context, chunk, content, path):
-    return (yield _save_any(context, chunk, json.dumps(content).encode('utf-8'), path, 'notebook', None))
+def _save_notebook(config, chunk, content, path):
+    return (yield _save_any(config, chunk, json.dumps(content).encode('utf-8'), path, 'notebook', None))
 
 
 @gen.coroutine
-def _save_file_base64(context, chunk, content, path):
-    return (yield _save_any(context, chunk, base64.b64decode(content.encode('utf-8')), path, 'file', 'application/octet-stream'))
+def _save_file_base64(config, chunk, content, path):
+    return (yield _save_any(config, chunk, base64.b64decode(content.encode('utf-8')), path, 'file', 'application/octet-stream'))
 
 
 @gen.coroutine
-def _save_file_text(context, chunk, content, path):
-    return (yield _save_any(context, chunk, content.encode('utf-8'), path, 'file', 'text/plain'))
+def _save_file_text(config, chunk, content, path):
+    return (yield _save_any(config, chunk, content.encode('utf-8'), path, 'file', 'text/plain'))
 
 
 @gen.coroutine
-def _save_directory(context, chunk, content, path):
-    return (yield _save_any(context, chunk, b'', path + cortx_constants["FOLDER_SEPERATOR"], 'directory', None))
+def _save_directory(config, chunk, content, path):
+    return (yield _save_any(config, chunk, b'', path + cortx_constants["FOLDER_SEPERATOR"], 'directory', None))
 
 
 @gen.coroutine
-def _save_any(context, chunk, content_bytes, path, type, mimetype):
+def _save_any(config, chunk, content_bytes, path, type, mimetype):
 
     response = \
-        (yield _save_bytes(context, content_bytes, path, type, mimetype)) if chunk is None else \
-        (yield _save_chunk(context, chunk, content_bytes, path, type, mimetype))
+        (yield _save_bytes(config, content_bytes, path, type, mimetype)) if chunk is None else \
+        (yield _save_chunk(config, chunk, content_bytes, path, type, mimetype))
 
     return response
 
 
 @gen.coroutine
-def _save_chunk(context, chunk, content_bytes, path, type, mimetype):
+def _save_chunk(config, chunk, content_bytes, path, type, mimetype):
     # Chunks are 1-indexed
     if chunk == 1:
-        context.multipart_uploads[path] = []
-    context.multipart_uploads[path].append(content_bytes)
+        config.multipart_uploads[path] = []
+    config.multipart_uploads[path].append(content_bytes)
 
     # -1 is the last chunk
     if chunk == -1:
-        combined_bytes = b''.join(context.multipart_uploads[path])
-        del context.multipart_uploads[path]
-        return (yield _save_bytes(context, combined_bytes, path, type, mimetype))
+        combined_bytes = b''.join(config.multipart_uploads[path])
+        del config.multipart_uploads[path]
+        return (yield _save_bytes(config, combined_bytes, path, type, mimetype))
     else:
         return _saved_model(path, type, mimetype, datetime.datetime.now())
 
 
 @gen.coroutine
-def _save_bytes(context, content_bytes, path, type, mimetype):
+def _save_bytes(config, content_bytes, path, type, mimetype):
 
-    object_name = _key(context, path)
-    response = _put_object(context, context.bucket_name, content_bytes, object_name)
+    object_name = _key(config, path)
+    response = _put_object(config, config.bucket_name, content_bytes, object_name)
     last_modified = f"{datetime.datetime.now():%a, %d %b %Y %H:%M:%S GMT}"
 
     return _saved_model(path, type, mimetype, last_modified)
@@ -459,14 +450,14 @@ def _saved_model(path, type, mimetype, last_modified):
 
 
 @gen.coroutine
-def _increment_filename(context, filename, path='', insert=''):
+def _increment_filename(config, filename, path='', insert=''):
     basename, dot, ext = filename.partition('.')
     suffix = dot + ext
 
     for i in itertools.count():
         insert_i = f'{insert}{i}' if i else ''
         name = f'{basename}{insert_i}{suffix}'
-        if not (yield _exists(context, f'/{path}/{name}')):
+        if not (yield _exists(config, f'/{path}/{name}')):
             break
     return name
 
@@ -476,17 +467,17 @@ def _checkpoint_path(path, checkpoint_id):
 
 
 @gen.coroutine
-def _create_checkpoint(context, path):
-    model = yield _get(context, path, content=True, type=None, format=None)
+def _create_checkpoint(config, path):
+    model = yield _get(config, path, content=True, type=None, format=None)
     type = model['type']
     content = model['content']
     format = model['format']
 
     checkpoint_id = str(int(time.time() * 1000000))
     checkpoint_path = _checkpoint_path(path, checkpoint_id)
-    yield SAVERS[(type, format)](context, None, content, checkpoint_path)
+    yield SAVERS[(type, format)](config, None, content, checkpoint_path)
     # This is a new object, so shouldn't be any eventual consistency issues
-    checkpoint = yield GETTERS[(type, format)](context, checkpoint_path, False)
+    checkpoint = yield GETTERS[(type, format)](config, checkpoint_path, False)
     return {
         'id': checkpoint_id,
         'last_modified': checkpoint['last_modified'],
@@ -494,29 +485,29 @@ def _create_checkpoint(context, path):
 
 
 @gen.coroutine
-def _get_model_at_checkpoint(context, type, checkpoint_id, path):
-    format = _format_from_type_and_path(context, type, path)
+def _get_model_at_checkpoint(config, type, checkpoint_id, path):
+    format = _format_from_type_and_path(config, type, path)
     checkpoint_path = _checkpoint_path(path, checkpoint_id)
-    return (yield GETTERS[(type, format)](context, checkpoint_path, True))
+    return (yield GETTERS[(type, format)](config, checkpoint_path, True))
 
 
 @gen.coroutine
-def _restore_checkpoint(context, checkpoint_id, path):
-    type = (yield _get(context, path, content=False, type=None, format=None))['type']
-    model = yield _get_model_at_checkpoint(context, type, checkpoint_id, path)
-    yield _save(context, model, path)
+def _restore_checkpoint(config, checkpoint_id, path):
+    type = (yield _get(config, path, content=False, type=None, format=None))['type']
+    model = yield _get_model_at_checkpoint(config, type, checkpoint_id, path)
+    yield _save(config, model, path)
 
 
 @gen.coroutine
-def _delete_checkpoint(context, checkpoint_id, path):
+def _delete_checkpoint(config, checkpoint_id, path):
     checkpoint_path = _checkpoint_path(path, checkpoint_id)
-    yield _delete(context, checkpoint_path)
+    yield _delete(config, checkpoint_path)
 
 
 @gen.coroutine
-def _list_checkpoints(context, path):
-    key_prefix = _key(context, path + '/' + cortx_constants["CHECKPOINT_NAME"] + '/')
-    keys, _ = yield _list_immediate_child_keys_and_directories(context, key_prefix)
+def _list_checkpoints(config, path):
+    key_prefix = _key(config, path + '/' + cortx_constants["CHECKPOINT_NAME"] + '/')
+    keys, _ = yield _list_immediate_child_keys_and_directories(config, key_prefix)
     return [
         {
             'id': key[(key.rfind('/' + cortx_constants["CHECKPOINT_NAME"] + '/') + len('/' + cortx_constants["CHECKPOINT_NAME"] + '/')):],
@@ -527,16 +518,16 @@ def _list_checkpoints(context, path):
 
 
 @gen.coroutine
-def _rename(context, old_path, new_path):
-    if (not (yield _exists(context, old_path))):
+def _rename(config, old_path, new_path):
+    if (not (yield _exists(config, old_path))):
         raise HTTPServerError(400, "Source does not exist")
 
-    if (yield _exists(context, new_path)):
+    if (yield _exists(config, new_path)):
         raise HTTPServerError(400, "Target already exists")
 
-    type = yield _type_from_path(context, old_path)
-    old_key = _key(context, old_path)
-    new_key = _key(context, new_path)
+    type = yield _type_from_path(config, old_path)
+    old_key = _key(config, old_path)
+    new_key = _key(config, new_path)
 
     def replace_key_prefix(string):
         return new_key + string[len(old_key):]
@@ -547,7 +538,7 @@ def _rename(context, old_path, new_path):
 
     renames = object_key + [
         (key, replace_key_prefix(key))
-        for (key, _) in (yield _list_all_descendant_keys(context, old_key + '/'))
+        for (key, _) in (yield _list_all_descendant_keys(config, old_key + '/'))
     ]
 
     # We can't really do a transaction on S3, and not sure if we can trust that on any error
@@ -555,27 +546,27 @@ def _rename(context, old_path, new_path):
     # isn't bulletproof due to eventual consistency. So we risk duplicate files over risking
     # deleted files
     for (old_key, new_key) in object_key + sorted(renames, key=lambda k: _copy_sort_key(k[0])):
-        yield _copy_key(context, old_key, new_key)
+        yield _copy_key(config, old_key, new_key)
 
     for (old_key, _) in sorted(renames, key=lambda k: _delete_sort_key(k[0])) + object_key:
-        yield _delete_key(context, old_key)
+        yield _delete_key(config, old_key)
 
-    return (yield _get(context, new_path, content=False, type=None, format=None))
+    return (yield _get(config, new_path, content=False, type=None, format=None))
 
 
 @gen.coroutine
-def _copy_key(context, old_key, new_key):
+def _copy_key(config, old_key, new_key):
 
-    yield _copy_object(context, context.bucket_name, old_key, new_key)
+    yield _copy_object(config, config.bucket_name, old_key, new_key)
 
 
 @gen.coroutine
-def _delete(context, path):
+def _delete(config, path):
     if not path:
         raise HTTPServerError(400, "Can't delete root")
 
-    type = _type_from_path(context, path)
-    root_key = _key(context, path)
+    type = _type_from_path(config, path)
+    root_key = _key(config, path)
 
     object_key = \
         [] if type == 'directory' else \
@@ -583,21 +574,21 @@ def _delete(context, path):
 
     descendant_keys = [
         key
-        for (key, _) in (yield _list_all_descendant_keys(context, root_key + '/'))
+        for (key, _) in (yield _list_all_descendant_keys(config, root_key + '/'))
     ]
 
     for key in sorted(descendant_keys, key=_delete_sort_key) + object_key:
-        yield _delete_key(context, key)
+        yield _delete_key(config, key)
 
 
 @gen.coroutine
-def _delete_key(context, key):
-    yield _delete_object(context, context.bucket_name, key)
+def _delete_key(config, key):
+    yield _delete_object(config, config.bucket_name, key)
 
 
 @gen.coroutine
-def _new_untitled(context, path, type, ext):
-    if not (yield _dir_exists(context, path)):
+def _new_untitled(config, path, type, ext):
+    if not (yield _dir_exists(config, path)):
         raise HTTPServerError(404, 'No such directory: %s' % path)
 
     model_type = \
@@ -616,17 +607,17 @@ def _new_untitled(context, path, type, ext):
         '.ipynb' if model_type == 'notebook' else \
         ext
 
-    name = yield _increment_filename(context, untitled + ext, path, insert=insert)
+    name = yield _increment_filename(config, untitled + ext, path, insert=insert)
     path = u'{0}/{1}'.format(path, name)
 
     model = {
         'type': model_type,
     }
-    return (yield _new(context, model, path))
+    return (yield _new(config, model, path))
 
 
 @gen.coroutine
-def _new(context, model, path):
+def _new(config, model, path):
     if model is None:
         model = {}
 
@@ -639,12 +630,12 @@ def _new(context, model, path):
         model['content'] = ''
         model['format'] = 'text'
 
-    return (yield _save(context, model, path))
+    return (yield _save(config, model, path))
 
 
 @gen.coroutine
-def _copy(context, from_path, to_path):
-    model = yield _get(context, from_path, content=False, type=None, format=None)
+def _copy(config, from_path, to_path):
+    model = yield _get(config, from_path, content=False, type=None, format=None)
     if model['type'] == 'directory':
         raise HTTPServerError(400, "Can't copy directories")
 
@@ -656,16 +647,16 @@ def _copy(context, from_path, to_path):
         to_path if to_path is not None else \
         from_dir
 
-    if (yield _dir_exists(context, to_path)):
+    if (yield _dir_exists(config, to_path)):
         copy_pat = re.compile(r'\-Copy\d*\.')
         name = copy_pat.sub(u'.', from_name)
-        to_name = yield _increment_filename(context, name, to_path, insert='-Copy')
+        to_name = yield _increment_filename(config, name, to_path, insert='-Copy')
         to_path = u'{0}/{1}'.format(to_path, to_name)
 
-    from_key = _key(context, from_path)
-    to_key = _key(context, to_path)
+    from_key = _key(config, from_path)
+    to_key = _key(config, to_path)
 
-    yield _copy_key(context, from_key, to_key)
+    yield _copy_key(config, from_key, to_key)
     return {
         **model,
         'name': to_name,
@@ -674,28 +665,28 @@ def _copy(context, from_path, to_path):
 
 
 @gen.coroutine
-def _list_immediate_child_keys_and_directories(context, key_prefix):
-    return (yield _list_keys(context, key_prefix, '/'))
+def _list_immediate_child_keys_and_directories(config, key_prefix):
+    return (yield _list_keys(config, key_prefix, '/'))
 
 
 @gen.coroutine
-def _list_all_descendant_keys(context, key_prefix):
-    return (yield _list_keys(context, key_prefix, ''))[0]
+def _list_all_descendant_keys(config, key_prefix):
+    return (yield _list_keys(config, key_prefix, ''))[0]
 
 
 @gen.coroutine
-def _list_keys(context, key_prefix, delimiter):
+def _list_keys(config, key_prefix, delimiter):
 
     max_keys = 1000
 
     @gen.coroutine
     def _list_first_page():
-        response = yield _list_objects(context, context.bucket_name, key_prefix, delimiter, max_keys)
+        response = yield _list_objects(config, config.bucket_name, key_prefix, delimiter, max_keys)
         return _parse_list_response(response)
 
     @gen.coroutine
     def _list_later_page(token):
-        response = yield _list_objects(context, context.bucket_name, key_prefix, delimiter, max_keys, token)
+        response = yield _list_objects(config, config.bucket_name, key_prefix, delimiter, max_keys, token)
 
         return _parse_list_response(response)
 
@@ -771,10 +762,10 @@ SAVERS = {
 
 
 @gen.coroutine
-def _head_object(context, bucket, key):
-    credentials = yield context.cortx_authenticator()
+def _head_object(config, bucket, key):
+    credentials = yield config.cortx_authenticator()
     s3_client = boto3.client('s3', aws_access_key_id=credentials.access_key_id,
-                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url= context.endpoint_url)
+                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url= config.endpoint_url)
     response = s3_client.list_objects_v2(
         Bucket=bucket,
         Prefix=key,
@@ -787,50 +778,50 @@ def _head_object(context, bucket, key):
 
 
 @gen.coroutine
-def _put_object(context, bucket, body, object_name):
-    credentials = yield context.cortx_authenticator()
+def _put_object(config, bucket, body, object_name):
+    credentials = yield config.cortx_authenticator()
     s3_client = boto3.client('s3', aws_access_key_id=credentials.access_key_id,
-                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url= context.endpoint_url)
+                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url= config.endpoint_url)
     return s3_client.put_object(Body=body, Bucket=bucket, Key=object_name)
 
 @gen.coroutine
-def _get_object(context, bucket, object_name):
-    credentials = yield context.cortx_authenticator()
+def _get_object(config, bucket, object_name):
+    credentials = yield config.cortx_authenticator()
     s3_client = boto3.client('s3', aws_access_key_id=credentials.access_key_id,
-                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url= context.endpoint_url)
+                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url= config.endpoint_url)
     return s3_client.get_object(Bucket=bucket, Key=object_name)
 
 @gen.coroutine
-def _list_buckets(context):
+def _list_buckets(config):
     # Retrieve the list of existing buckets
-    credentials = yield context.cortx_authenticator()
+    credentials = yield config.cortx_authenticator()
     s3_client = boto3.client('s3', aws_access_key_id=credentials.access_key_id,
-                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url = context.endpoint_url)
+                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url = config.endpoint_url)
     return s3_client.list_buckets()
 
 @gen.coroutine
-def _copy_object(context, bucket, source_file, destination_file):
-    credentials = yield context.cortx_authenticator()
+def _copy_object(config, bucket, source_file, destination_file):
+    credentials = yield config.cortx_authenticator()
     s3_client = boto3.client('s3', aws_access_key_id=credentials.access_key_id,
-                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url = context.endpoint_url)
-    response = yield _get_object(context, context.bucket_name, source_file)
+                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url = config.endpoint_url)
+    response = yield _get_object(config, config.bucket_name, source_file)
     file_bytes = response['Body'].read()
-    response = _put_object(context, context.bucket_name, file_bytes, destination_file)
+    response = _put_object(config, config.bucket_name, file_bytes, destination_file)
     last_modified = f"{datetime.datetime.now():%a, %d %b %Y %H:%M:%S GMT}"
     return _saved_model(destination_file.split('/')[-1], 'notebook', None, last_modified)
 
 @gen.coroutine
-def _delete_object(context, bucket, file_name):
-    credentials = yield context.cortx_authenticator()
+def _delete_object(config, bucket, file_name):
+    credentials = yield config.cortx_authenticator()
     s3_client = boto3.client('s3', aws_access_key_id=credentials.access_key_id,
-                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url = context.endpoint_url)
+                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url = config.endpoint_url)
     return s3_client.delete_object(Bucket=bucket, Key=file_name)
 
 @gen.coroutine
-def _list_objects(context, bucket, prefix, delimiter, max_keys, token=''):
-    credentials = yield context.cortx_authenticator()
+def _list_objects(config, bucket, prefix, delimiter, max_keys, token=''):
+    credentials = yield config.cortx_authenticator()
     s3_client = boto3.client('s3', aws_access_key_id=credentials.access_key_id,
-                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url = context.endpoint_url)
+                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url = config.endpoint_url)
     if token:
         return s3_client.list_objects_v2(
             Bucket=bucket,
